@@ -43,11 +43,17 @@ bws3Design <- function() {
   
   ##### Output Frame #####
   outputFrame <- tkframe(top)
+  designFrame <- tkframe(outputFrame)
+  saveFrame   <- tkframe(outputFrame)
 
   # Choice sets
   designName <- tclVar(dialog.values$designName)
-  design     <- ttkentry(outputFrame, width = "20", 
+  design     <- ttkentry(designFrame, width = "14", 
                          textvariable = designName)
+  # Save option
+  saveVariable <- tclVar(dialog.values$saveVariable)
+  saveCheckBox <- ttkcheckbutton(saveFrame, variable = saveVariable)
+
 
   ##### Input Frame #####
   inputsFrame       <- tkframe(top)
@@ -59,7 +65,6 @@ bws3Design <- function() {
   tableFrame        <- tkframe(TABLEFrame)
   rightFrame        <- tkframe(TABLEFrame)
   AttrCheckBoxFrame <- tkframe(rightFrame)
-  saveFrame        <- tkframe(inputsFrame)
   
   # Design method
   radioButtons(
@@ -73,19 +78,19 @@ bws3Design <- function() {
   # Number of alternatives per set (without the output option)
   nAlternativesName <- tclVar(dialog.values$nAlternativesName)
   nAlternatives     <- ttkentry(AltBlkRngFrame,
-                                width = "10",
+                                width = "7",
                                 textvariable = nAlternativesName)
   
   # Number of blocks
   nBlocksName <- tclVar(dialog.values$nBlocksName)
   nBlocks     <- ttkentry(AltBlkRngFrame,
-                          width = "10",
+                          width = "7",
                           textvariable = nBlocksName)
 
   # Seed for RNG
   RNGseedName <- tclVar(dialog.values$RNGseedName)
   RNGseed     <- ttkentry(RNGFrame,
-                          width = "10",
+                          width = "7",
                           textvariable = RNGseedName)
 
   # RNG option
@@ -159,9 +164,6 @@ bws3Design <- function() {
   A6Var <- tclVar(dialog.values$A6Var)
   A6CheckBox <- ttkcheckbutton(AttrCheckBoxFrame, variable = A6Var)
   
-  # Save option
-  saveVariable <- tclVar(dialog.values$saveVariable)
-  saveCheckBox <- ttkcheckbutton(saveFrame, variable = saveVariable)
   
   ##### onOK Function #####
   onOK <- function() {
@@ -311,10 +313,22 @@ bws3Design <- function() {
                reset       = "resetBws3Table",
                apply       = "bws3Design")
   # Output
+  ## Design
   tkgrid(
-    labelRcmdr(outputFrame,
+    labelRcmdr(designFrame,
                text = gettextRcmdr("Name for design ")),
     design, sticky = "w")
+
+  ## Save choice sets
+  tkgrid(
+    saveCheckBox,
+    labelRcmdr(
+      saveFrame,
+      text = gettextRcmdr("Save to file")),
+    sticky = "w")
+
+  tkgrid(designFrame, labelRcmdr(outputFrame, text = "   "),
+         saveFrame, sticky = "w")
   tkgrid(outputFrame, sticky = "w")
 
   # Blank line
@@ -386,18 +400,6 @@ bws3Design <- function() {
     sticky = "w")
   tkgrid(RNGoptionFrame, sticky = "w")
   
-  # Blank line
-  tkgrid(labelRcmdr(inputsFrame, text = ""))
-
-  # Save choice sets
-  tkgrid(
-    saveCheckBox,
-      labelRcmdr(
-        saveFrame,
-        text = gettextRcmdr("Save the resultant choice sets")),
-    sticky = "w")
-  tkgrid(saveFrame, sticky = "w")
-    
   tkgrid(inputsFrame, sticky = "w")
 
   # OK Cancel Help Buttons
@@ -407,7 +409,7 @@ bws3Design <- function() {
 }
 
 resetBws3Table <- function() {
-  putRcmdr("savedTableAttributes", NULL)
+  putRcmdr("savedTable", NULL)
   putDialog("bws3Design", NULL)
   bws3Design()
 }
@@ -424,7 +426,7 @@ bws3Questions <- function() {
 
   # Choice sets
   designName <- tclVar(dialog.values$designName)
-  design <- ttkentry(inputsFrame, width = "20",
+  design <- ttkentry(inputsFrame, width = "14",
                      textvariable = designName)
 
   ##### onOK Function #####
@@ -479,12 +481,16 @@ bws3Dataset <- function() {
   ###### Output frame
   outputFrame      <- tkframe(top)
   datasetnameFrame <- tkframe(outputFrame)
-  activeFrame      <- tkframe(outputFrame)
+  saveFrame        <- tkframe(outputFrame)
 
   # output name
   datasetName <- tclVar(dialog.values$ini.datasetName)
-  dataset <- ttkentry(datasetnameFrame, width = "20",
-                      textvariable = datasetName)
+  dataset     <- ttkentry(datasetnameFrame, width = "14",
+                          textvariable = datasetName)
+
+  # save option
+  saveVariable <- tclVar(dialog.values$saveVariable)
+  saveCheckBox <- ttkcheckbutton(saveFrame, variable = saveVariable)
 
 
   ###### Inputs frame
@@ -497,26 +503,22 @@ bws3Dataset <- function() {
   radio2Frame  <- tkframe(leftFrame)
   radio3Frame  <- tkframe(leftFrame)
   optoutFrame  <- tkframe(leftFrame)
-  saveFrame    <- tkframe(leftFrame)
   rowsFrame    <- tkframe(leftFrame)
   letterFrame  <- tkframe(leftFrame)
 
 
   # choice.sets
   designName <- tclVar(dialog.values$ini.designName)
-  design <- ttkentry(objectsFrame, width = "20", textvariable = designName)
+  design <- ttkentry(objectsFrame, width = "14", textvariable = designName)
 
   # id
   idName <- tclVar(dialog.values$ini.idName)
-  id <- ttkentry(objectsFrame, width = "20", textvariable = idName)
+  id <- ttkentry(objectsFrame, width = "14", textvariable = idName)
 
   # opt-out option
   optoutVariable <- tclVar(dialog.values$optoutVariable)
   optoutCheckBox <- ttkcheckbutton(optoutFrame, variable = optoutVariable)
 
-  # save option
-  saveVariable <- tclVar(dialog.values$saveVariable)
-  saveCheckBox <- ttkcheckbutton(saveFrame, variable = saveVariable)
 
   ### Frame in right
   rightFrame  <- tkframe(inputsFrame)
@@ -735,8 +737,14 @@ bws3Dataset <- function() {
   tkgrid(labelRcmdr(datasetnameFrame,
     text = gettextRcmdr("Name for data set ")),
     dataset, sticky = "w")
-  tkgrid(datasetnameFrame, sticky = "w")
+  tkgrid(saveCheckBox,
+         labelRcmdr(saveFrame, text = gettextRcmdr("Save to file")),
+         sticky = "w")
+  tkgrid(datasetnameFrame, labelRcmdr(outputFrame, text = "   "),
+         saveFrame, sticky = "w")
   tkgrid(outputFrame, sticky = "w")
+
+  # Blank line
   tkgrid(labelRcmdr(top, text = ""))
 
   # Inputs
@@ -761,11 +769,6 @@ bws3Dataset <- function() {
          sticky = "w")
   tkgrid(optoutFrame, sticky = "w")
 
-  tkgrid(labelRcmdr(saveFrame, text = gettextRcmdr("")), sticky = "w")
-  tkgrid(saveCheckBox,
-         labelRcmdr(saveFrame, text = gettextRcmdr("Save the data sets")),
-         sticky = "w")
-  tkgrid(saveFrame, sticky = "w")
 
   tkgrid(labelRcmdr(
            tableFrame,
@@ -931,7 +934,7 @@ bws3Fitmodel <- function() {
   UpdateModelNumber()
   modelName  <- tclVar(paste0("BWS3model.", getRcmdr("modelNumber")))
   modelFrame <- tkframe(top)
-  model      <- ttkentry(modelFrame, width = "20", textvariable = modelName)
+  model      <- ttkentry(modelFrame, width = "17", textvariable = modelName)
 
   
   ##### Input Frame #####
@@ -1030,7 +1033,10 @@ bws3Fitmodel <- function() {
   ## Response variable
   tkgrid(labelRcmdr(responseVarFrame,
                     text = gettextRcmdr("Response variable ")),
-         responseVar, sticky = "w")
+         labelRcmdr(responseVarFrame,
+                    text = tclvalue(responseVarName),
+                    relief = "solid", foreground = "green"),
+         sticky = "w")
   tkgrid(responseVarFrame, sticky = "w")
 
   ## Independent variables (Modified 0.1-3)
@@ -1040,7 +1046,10 @@ bws3Fitmodel <- function() {
   ## Stratification variable
   tkgrid(labelRcmdr(strataVarFrame,
                     text = gettextRcmdr("Stratification variable ")),
-         strataVar, sticky = "w")
+         labelRcmdr(strataVarFrame,
+                    text = tclvalue(strataVarName),
+                    relief = "solid", foreground = "green"),
+         sticky = "w")
   tkgrid(strataVarFrame, sticky = "w")
   tkgrid(strataFrame, sticky = "w")
 
@@ -1091,7 +1100,7 @@ bws3Mwtp <- function() {
   # output
   outputFrame <- tkframe(top)
   outputName  <- tclVar(dialog.values$outputName)
-  output      <- ttkentry(outputFrame, width = "20", textvariable = outputName)
+  output      <- ttkentry(outputFrame, width = "17", textvariable = outputName)
   
   
   ##### Input Frame #####
@@ -1130,16 +1139,16 @@ bws3Mwtp <- function() {
   
   ## Confidence level
   confLevelName <- tclVar(dialog.values$confLevelName)
-  confLevel     <- ttkentry(clFrame, width = "6",
+  confLevel     <- ttkentry(clFrame, width = "7",
                             textvariable = confLevelName)
 
   NdrawsValue   <- tclVar(dialog.values$NdrawsValue)
-  Ndraws        <- ttkentry(optionsKRFrame, width = "6",
+  Ndraws        <- ttkentry(optionsKRFrame, width = "7",
                             textvariable = NdrawsValue)
   
   ## Random number generator seed
   RNGseedName <- tclVar(dialog.values$RNGseedName)
-  RNGseed     <- ttkentry(optionsKRFrame, width = "10",
+  RNGseed     <- ttkentry(optionsKRFrame, width = "7",
                           textvariable = RNGseedName)
   
   
